AsyncDirectiveOutboxWriter

Trait AsyncDirectiveOutboxWriter 

pub trait AsyncDirectiveOutboxWriter: AsyncDirectiveOutboxReader {
    // Required methods
    fn record_directive_submitter_submission<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        request_id: &'life1 str,
        submitter_address: &'life2 Address,
        submitter_nonce: u64,
    ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait;
    fn persist_directive_transaction_update<'life0, 'life1, 'life2, 'life3, 'async_trait>(
        &'life0 self,
        request_id: &'life1 str,
        status: TransactionStatus,
        tx_hash: Option<&'life2 str>,
        error: Option<&'life3 str>,
    ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait,
             'life3: 'async_trait;
}

Required Methods

fn record_directive_submitter_submission<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, request_id: &'life1 str, submitter_address: &'life2 Address, submitter_nonce: u64, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Store the submitter-owned submission pointer for a directive.

The directive outbox does not own transaction attempts, receipts, or replacement state. It stores only the submitter identity and nonce needed to query submitter-owned state.

fn persist_directive_transaction_update<'life0, 'life1, 'life2, 'life3, 'async_trait>( &'life0 self, request_id: &'life1 str, status: TransactionStatus, tx_hash: Option<&'life2 str>, error: Option<&'life3 str>, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait, 'life3: 'async_trait,

Persist transaction-submitter status updates for a directive.

Failed and expired withdrawal directives are terminal for automatic delivery, but remain operator-reconciled. This method must not refund or otherwise restore withdrawal debits.

Implementors