pub trait DirectiveOutboxReader: Send + Sync {
// Required methods
fn claim_next_directive_outbox_item_sync(
&self,
) -> Result<Option<DirectiveOutboxRow>>;
fn get_directive_status_sync(
&self,
directive_id: &str,
) -> Result<Option<DirectiveStatusRow>>;
fn get_withdrawal_history_sync(
&self,
wallet: &WalletAddress,
limit: i64,
) -> Result<Vec<DirectiveStatusRow>>;
fn list_directive_outbox_delivery_metrics_sync(
&self,
) -> Result<Vec<DirectiveOutboxDeliveryMetricsRow>>;
fn list_recent_directive_outbox_rows_sync(
&self,
limit: i64,
offset: i64,
) -> Result<Vec<DirectiveOutboxRecentRow>>;
}Required Methods
fn claim_next_directive_outbox_item_sync( &self, ) -> Result<Option<DirectiveOutboxRow>>
Sourcefn get_directive_status_sync(
&self,
directive_id: &str,
) -> Result<Option<DirectiveStatusRow>>
fn get_directive_status_sync( &self, directive_id: &str, ) -> Result<Option<DirectiveStatusRow>>
Look up the delivery status of a single directive by its ID.
Sourcefn get_withdrawal_history_sync(
&self,
wallet: &WalletAddress,
limit: i64,
) -> Result<Vec<DirectiveStatusRow>>
fn get_withdrawal_history_sync( &self, wallet: &WalletAddress, limit: i64, ) -> Result<Vec<DirectiveStatusRow>>
Return withdrawal directive history for a wallet, most recent first.
Sourcefn list_directive_outbox_delivery_metrics_sync(
&self,
) -> Result<Vec<DirectiveOutboxDeliveryMetricsRow>>
fn list_directive_outbox_delivery_metrics_sync( &self, ) -> Result<Vec<DirectiveOutboxDeliveryMetricsRow>>
Return retryable directive delivery backlog grouped by stable low-cardinality labels.
Sourcefn list_recent_directive_outbox_rows_sync(
&self,
limit: i64,
offset: i64,
) -> Result<Vec<DirectiveOutboxRecentRow>>
fn list_recent_directive_outbox_rows_sync( &self, limit: i64, offset: i64, ) -> Result<Vec<DirectiveOutboxRecentRow>>
Return recent directive outbox rows for operator debugging.