pub trait RsmCreditReader: Send + Sync {
// Required methods
fn directive_outbox_exists_sync(&self, directive_id: &str) -> Result<bool>;
fn get_max_rsm_deposit_credit_observed_block<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Option<u64>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_exchange_cash_ledger_watermark_sync(&self) -> Result<Option<i64>>;
fn get_option_instrument_for_credit<'life0, 'life1, 'async_trait>(
&'life0 self,
token: &'life1 WalletAddress,
) -> Pin<Box<dyn Future<Output = Result<Option<OptionInstrumentForCredit>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn list_recent_cash_deposit_monitoring_rows<'life0, 'async_trait>(
&'life0 self,
limit: i64,
offset: i64,
) -> Pin<Box<dyn Future<Output = Result<Vec<DepositMonitoringRow>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Methods
Sourcefn directive_outbox_exists_sync(&self, directive_id: &str) -> Result<bool>
fn directive_outbox_exists_sync(&self, directive_id: &str) -> Result<bool>
Check whether a directive outbox row exists for the given directive_id.
Sourcefn get_max_rsm_deposit_credit_observed_block<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Option<u64>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_max_rsm_deposit_credit_observed_block<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Option<u64>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Return the replay watermark for RSM deposit credits.
Sourcefn get_exchange_cash_ledger_watermark_sync(&self) -> Result<Option<i64>>
fn get_exchange_cash_ledger_watermark_sync(&self) -> Result<Option<i64>>
Return the replay watermark for exchange cash ledger events.
Sourcefn get_option_instrument_for_credit<'life0, 'life1, 'async_trait>(
&'life0 self,
token: &'life1 WalletAddress,
) -> Pin<Box<dyn Future<Output = Result<Option<OptionInstrumentForCredit>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_option_instrument_for_credit<'life0, 'life1, 'async_trait>(
&'life0 self,
token: &'life1 WalletAddress,
) -> Pin<Box<dyn Future<Output = Result<Option<OptionInstrumentForCredit>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Look up an option instrument by its on-chain token address.
Sourcefn list_recent_cash_deposit_monitoring_rows<'life0, 'async_trait>(
&'life0 self,
limit: i64,
offset: i64,
) -> Pin<Box<dyn Future<Output = Result<Vec<DepositMonitoringRow>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_recent_cash_deposit_monitoring_rows<'life0, 'async_trait>(
&'life0 self,
limit: i64,
offset: i64,
) -> Pin<Box<dyn Future<Output = Result<Vec<DepositMonitoringRow>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Return recent cash deposit attribution rows for admin monitoring.